// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
import { __assign, __awaiter, __extends, __generator } from "tslib";
import { delay } from "@azure/core-http";
import { Poller } from "@azure/core-lro";
import { makeRecoverDeletedSecretPollOperation } from "./operation";
/**
 * Class that deletes a poller that waits until a secret finishes being deleted
 */
var RecoverDeletedSecretPoller = /** @class */ (function (_super) {
    __extends(RecoverDeletedSecretPoller, _super);
    function RecoverDeletedSecretPoller(options) {
        var _this = this;
        var client = options.client, name = options.name, requestOptions = options.requestOptions, _a = options.intervalInMs, intervalInMs = _a === void 0 ? 2000 : _a, resumeFrom = options.resumeFrom;
        var state;
        if (resumeFrom) {
            state = JSON.parse(resumeFrom).state;
        }
        var operation = makeRecoverDeletedSecretPollOperation(__assign(__assign({}, state), { name: name,
            requestOptions: requestOptions,
            client: client }));
        _this = _super.call(this, operation) || this;
        _this.intervalInMs = intervalInMs;
        return _this;
    }
    /**
     * The method used by the poller to wait before attempting to update its operation.
     * @memberof RecoverDeletedSecretPoller
     */
    RecoverDeletedSecretPoller.prototype.delay = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, delay(this.intervalInMs)];
            });
        });
    };
    return RecoverDeletedSecretPoller;
}(Poller));
export { RecoverDeletedSecretPoller };
//# sourceMappingURL=poller.js.map